@@ -16,14 +16,14 @@
 // OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-use std::{mem, slice, cell};
-use std::ffi::CStr;
-use ffi;
-use libc;
 use err::{self, PyResult};
 use exc;
-use python::{Python, PyDrop};
+use ffi;
+use libc;
 use objects::PyObject;
+use python::{PyDrop, Python};
+use std::ffi::CStr;
+use std::{cell, mem, slice};
 
 /// Allows access to the underlying buffer used by a python object such as `bytes`, `bytearray` or `array.array`.
 pub struct PyBuffer(Box<ffi::Py_buffer>); // use Box<> because Python expects that the Py_buffer struct has a stable memory address
@@ -39,7 +39,7 @@ pub enum ElementType {
     UnsignedInteger { bytes: usize },
     Bool,
     Float { bytes: usize },
-    Unknown
+    Unknown,
 }
 
 impl ElementType {
@@ -51,7 +51,7 @@ impl ElementType {
             match slice[0] {
                 b'@' => native_element_type_from_type_char(slice[1]),
                 b'=' | b'<' | b'>' | b'!' => standard_element_type_from_type_char(slice[1]),
-                _ => ElementType::Unknown
+                _ => ElementType::Unknown,
             }
         } else {
             ElementType::Unknown
@@ -62,24 +62,50 @@ impl ElementType {
 fn native_element_type_from_type_char(type_char: u8) -> ElementType {
     use self::ElementType::*;
     match type_char {
-        b'c' => UnsignedInteger { bytes: mem::size_of::<libc::c_char>() },
-        b'b' => SignedInteger   { bytes: mem::size_of::<libc::c_schar>() },
-        b'B' => UnsignedInteger { bytes: mem::size_of::<libc::c_uchar>() },
+        b'c' => UnsignedInteger {
+            bytes: mem::size_of::<libc::c_char>(),
+        },
+        b'b' => SignedInteger {
+            bytes: mem::size_of::<libc::c_schar>(),
+        },
+        b'B' => UnsignedInteger {
+            bytes: mem::size_of::<libc::c_uchar>(),
+        },
         b'?' => Bool,
-        b'h' => SignedInteger   { bytes: mem::size_of::<libc::c_short>() },
-        b'H' => UnsignedInteger { bytes: mem::size_of::<libc::c_ushort>() },
-        b'i' => SignedInteger   { bytes: mem::size_of::<libc::c_int>() },
-        b'I' => UnsignedInteger { bytes: mem::size_of::<libc::c_uint>() },
-        b'l' => SignedInteger   { bytes: mem::size_of::<libc::c_long>() },
-        b'L' => UnsignedInteger { bytes: mem::size_of::<libc::c_ulong>() },
-        b'q' => SignedInteger   { bytes: mem::size_of::<libc::c_longlong>() },
-        b'Q' => UnsignedInteger { bytes: mem::size_of::<libc::c_ulonglong>() },
-        b'n' => SignedInteger   { bytes: mem::size_of::<libc::ssize_t>() },
-        b'N' => UnsignedInteger { bytes: mem::size_of::<libc::size_t>() },
+        b'h' => SignedInteger {
+            bytes: mem::size_of::<libc::c_short>(),
+        },
+        b'H' => UnsignedInteger {
+            bytes: mem::size_of::<libc::c_ushort>(),
+        },
+        b'i' => SignedInteger {
+            bytes: mem::size_of::<libc::c_int>(),
+        },
+        b'I' => UnsignedInteger {
+            bytes: mem::size_of::<libc::c_uint>(),
+        },
+        b'l' => SignedInteger {
+            bytes: mem::size_of::<libc::c_long>(),
+        },
+        b'L' => UnsignedInteger {
+            bytes: mem::size_of::<libc::c_ulong>(),
+        },
+        b'q' => SignedInteger {
+            bytes: mem::size_of::<libc::c_longlong>(),
+        },
+        b'Q' => UnsignedInteger {
+            bytes: mem::size_of::<libc::c_ulonglong>(),
+        },
+        b'n' => SignedInteger {
+            bytes: mem::size_of::<libc::ssize_t>(),
+        },
+        b'N' => UnsignedInteger {
+            bytes: mem::size_of::<libc::size_t>(),
+        },
         b'e' => Float { bytes: 2 },
         b'f' => Float { bytes: 4 },
         b'd' => Float { bytes: 8 },
-        _ => Unknown
+        _ => Unknown,
     }
 }
 
@@ -87,21 +113,21 @@ fn standard_element_type_from_type_char(type_char: u8) -> ElementType {
     use self::ElementType::*;
     match type_char {
         b'c' => UnsignedInteger { bytes: 1 },
-        b'b' => SignedInteger   { bytes: 1 },
+        b'b' => SignedInteger { bytes: 1 },
         b'B' => UnsignedInteger { bytes: 1 },
         b'?' => Bool,
-        b'h' => SignedInteger   { bytes: 2 },
+        b'h' => SignedInteger { bytes: 2 },
         b'H' => UnsignedInteger { bytes: 2 },
-        b'i' => SignedInteger   { bytes: 4 },
+        b'i' => SignedInteger { bytes: 4 },
         b'I' => UnsignedInteger { bytes: 4 },
-        b'l' => SignedInteger   { bytes: 4 },
+        b'l' => SignedInteger { bytes: 4 },
         b'L' => UnsignedInteger { bytes: 4 },
-        b'q' => SignedInteger   { bytes: 8 },
+        b'q' => SignedInteger { bytes: 8 },
         b'Q' => UnsignedInteger { bytes: 8 },
         b'e' => Float { bytes: 2 },
         b'f' => Float { bytes: 4 },
         b'd' => Float { bytes: 8 },
-        _ => Unknown
+        _ => Unknown,
     }
 }
 
@@ -109,7 +135,7 @@ fn standard_element_type_from_type_char(type_char: u8) -> ElementType {
 fn is_matching_endian(c: u8) -> bool {
     match c {
         b'@' | b'=' | b'<' => true,
-        _ => false
+        _ => false,
     }
 }
 
@@ -117,7 +143,7 @@ fn is_matching_endian(c: u8) -> bool {
 fn is_matching_endian(c: u8) -> bool {
     match c {
         b'@' | b'=' | b'>' | b'!' => true,
-        _ => false
+        _ => false,
     }
 }
 
@@ -139,7 +165,10 @@ impl PyBuffer {
     pub fn get(py: Python, obj: &PyObject) -> PyResult<PyBuffer> {
         unsafe {
             let mut buf = Box::new(mem::zeroed::<ffi::Py_buffer>());
-            err::error_on_minusone(py, ffi::PyObject_GetBuffer(obj.as_ptr(), &mut *buf, ffi::PyBUF_FULL_RO))?;
+            err::error_on_minusone(
+                py,
+                ffi::PyObject_GetBuffer(obj.as_ptr(), &mut *buf, ffi::PyBUF_FULL_RO),
+            )?;
             validate(&buf);
             Ok(PyBuffer(buf))
         }
@@ -165,7 +194,7 @@ impl PyBuffer {
         unsafe {
             ffi::PyBuffer_GetPointer(
                 &*self.0 as *const ffi::Py_buffer as *mut ffi::Py_buffer,
-                indices.as_ptr() as *mut usize as *mut ::Py_ssize_t
+                indices.as_ptr() as *mut usize as *mut ::Py_ssize_t,
             )
         }
     }
@@ -177,7 +206,7 @@ impl PyBuffer {
     }
 
     /// Gets the size of a single element, in bytes.
-    /// Important exception: when requesting an unformatted buffer, item_size still has the value 
+    /// Important exception: when requesting an unformatted buffer, item_size still has the value
     #[inline]
     pub fn item_size(&self) -> usize {
         self.0.itemsize as usize
@@ -214,9 +243,7 @@ impl PyBuffer {
     /// However, dimensions of length 0 are possible and might need special attention.
     #[inline]
     pub fn shape(&self) -> &[usize] {
-        unsafe {
-            slice::from_raw_parts(self.0.shape as *const usize, self.0.ndim as usize)
-        }
+        unsafe { slice::from_raw_parts(self.0.shape as *const usize, self.0.ndim as usize) }
     }
 
     /// Returns an array that holds, for each dimension, the number of bytes to skip to get to the next element in the dimension.
@@ -225,9 +252,7 @@ impl PyBuffer {
     /// but a consumer MUST be able to handle the case `strides[n] <= 0`.
     #[inline]
     pub fn strides(&self) -> &[isize] {
-        unsafe {
-            slice::from_raw_parts(self.0.strides, self.0.ndim as usize)
-        }
+        unsafe { slice::from_raw_parts(self.0.strides, self.0.ndim as usize) }
     }
 
     /// An array of length ndim.
@@ -241,7 +266,10 @@ impl PyBuffer {
             if self.0.suboffsets.is_null() {
                 None
             } else {
-                Some(slice::from_raw_parts(self.0.suboffsets, self.0.ndim as usize))
+                Some(slice::from_raw_parts(
+                    self.0.suboffsets,
+                    self.0.ndim as usize,
+                ))
             }
         }
     }
@@ -261,7 +289,10 @@ impl PyBuffer {
     pub fn is_c_contiguous(&self) -> bool {
         unsafe {
             // Python 2.7 is not const-correct, so we need the cast to *mut
-            ffi::PyBuffer_IsContiguous(&*self.0 as *const ffi::Py_buffer as *mut ffi::Py_buffer, b'C' as libc::c_char) != 0
+            ffi::PyBuffer_IsContiguous(
+                &*self.0 as *const ffi::Py_buffer as *mut ffi::Py_buffer,
+                b'C' as libc::c_char,
+            ) != 0
         }
     }
 
@@ -270,7 +301,10 @@ impl PyBuffer {
     pub fn is_fortran_contiguous(&self) -> bool {
         unsafe {
             // Python 2.7 is not const-correct, so we need the cast to *mut
-            ffi::PyBuffer_IsContiguous(&*self.0 as *const ffi::Py_buffer as *mut ffi::Py_buffer, b'F' as libc::c_char) != 0
+            ffi::PyBuffer_IsContiguous(
+                &*self.0 as *const ffi::Py_buffer as *mut ffi::Py_buffer,
+                b'F' as libc::c_char,
+            ) != 0
         }
     }
 
@@ -289,7 +323,12 @@ impl PyBuffer {
             && self.is_c_contiguous()
             && T::is_compatible_format(self.format())
         {
-            unsafe { Some(slice::from_raw_parts(self.0.buf as *mut ReadOnlyCell<T>, self.item_count())) }
+            unsafe {
+                Some(slice::from_raw_parts(
+                    self.0.buf as *mut ReadOnlyCell<T>,
+                    self.item_count(),
+                ))
+            }
         } else {
             None
         }
@@ -312,7 +351,12 @@ impl PyBuffer {
             && self.is_c_contiguous()
             && T::is_compatible_format(self.format())
         {
-            unsafe { Some(slice::from_raw_parts(self.0.buf as *mut cell::Cell<T>, self.item_count())) }
+            unsafe {
+                Some(slice::from_raw_parts(
+                    self.0.buf as *mut cell::Cell<T>,
+                    self.item_count(),
+                ))
+            }
         } else {
             None
         }
@@ -327,13 +371,21 @@ impl PyBuffer {
     ///
     /// The returned slice uses type `Cell<T>` because it's theoretically possible for any call into the Python runtime
     /// to modify the values in the slice.
-    pub fn as_fortran_slice<'a, T: Element>(&'a self, _py: Python<'a>) -> Option<&'a [ReadOnlyCell<T>]> {
+    pub fn as_fortran_slice<'a, T: Element>(
+        &'a self,
+        _py: Python<'a>,
+    ) -> Option<&'a [ReadOnlyCell<T>]> {
         if mem::size_of::<T>() == self.item_size()
             && (self.0.buf as usize) % mem::align_of::<T>() == 0
             && self.is_fortran_contiguous()
             && T::is_compatible_format(self.format())
         {
-            unsafe { Some(slice::from_raw_parts(self.0.buf as *mut ReadOnlyCell<T>, self.item_count())) }
+            unsafe {
+                Some(slice::from_raw_parts(
+                    self.0.buf as *mut ReadOnlyCell<T>,
+                    self.item_count(),
+                ))
+            }
         } else {
             None
         }
@@ -349,14 +401,22 @@ impl PyBuffer {
     ///
     /// The returned slice uses type `Cell<T>` because it's theoretically possible for any call into the Python runtime
     /// to modify the values in the slice.
-    pub fn as_fortran_mut_slice<'a, T: Element>(&'a self, _py: Python<'a>) -> Option<&'a [cell::Cell<T>]> {
+    pub fn as_fortran_mut_slice<'a, T: Element>(
+        &'a self,
+        _py: Python<'a>,
+    ) -> Option<&'a [cell::Cell<T>]> {
         if !self.readonly()
             && mem::size_of::<T>() == self.item_size()
             && (self.0.buf as usize) % mem::align_of::<T>() == 0
             && self.is_fortran_contiguous()
             && T::is_compatible_format(self.format())
         {
-            unsafe { Some(slice::from_raw_parts(self.0.buf as *mut cell::Cell<T>, self.item_count())) }
+            unsafe {
+                Some(slice::from_raw_parts(
+                    self.0.buf as *mut cell::Cell<T>,
+                    self.item_count(),
+                ))
+            }
         } else {
             None
         }
@@ -371,7 +431,7 @@ impl PyBuffer {
     /// To check whether the buffer format is compatible before calling this method,
     /// you can use `<T as buffer::Element>::is_compatible_format(buf.format())`.
     /// Alternatively, `match buffer::ElementType::from_format(buf.format())`.
-    pub fn copy_to_slice<T: Element+Copy>(&self, py: Python, target: &mut [T]) -> PyResult<()> {
+    pub fn copy_to_slice<T: Element + Copy>(&self, py: Python, target: &mut [T]) -> PyResult<()> {
         self.copy_to_slice_impl(py, target, b'C')
     }
 
@@ -384,11 +444,20 @@ impl PyBuffer {
     /// To check whether the buffer format is compatible before calling this method,
     /// you can use `<T as buffer::Element>::is_compatible_format(buf.format())`.
     /// Alternatively, `match buffer::ElementType::from_format(buf.format())`.
-    pub fn copy_to_fortran_slice<T: Element+Copy>(&self, py: Python, target: &mut [T]) -> PyResult<()> {
+    pub fn copy_to_fortran_slice<T: Element + Copy>(
+        &self,
+        py: Python,
+        target: &mut [T],
+    ) -> PyResult<()> {
         self.copy_to_slice_impl(py, target, b'F')
     }
 
-    fn copy_to_slice_impl<T: Element+Copy>(&self, py: Python, target: &mut [T], fort: u8) -> PyResult<()> {
+    fn copy_to_slice_impl<T: Element + Copy>(
+        &self,
+        py: Python,
+        target: &mut [T],
+        fort: u8,
+    ) -> PyResult<()> {
         if mem::size_of_val(target) != self.len_bytes() {
             return slice_length_error(py);
         }
@@ -396,12 +465,15 @@ impl PyBuffer {
             return incompatible_format_error(py);
         }
         unsafe {
-            err::error_on_minusone(py, ffi::PyBuffer_ToContiguous(
-                target.as_ptr() as *mut libc::c_void,
-                &*self.0 as *const ffi::Py_buffer as *mut ffi::Py_buffer,
-                self.0.len,
-                fort as libc::c_char
-            ))
+            err::error_on_minusone(
+                py,
+                ffi::PyBuffer_ToContiguous(
+                    target.as_ptr() as *mut libc::c_void,
+                    &*self.0 as *const ffi::Py_buffer as *mut ffi::Py_buffer,
+                    self.0.len,
+                    fort as libc::c_char,
+                ),
+            )
         }
     }
 
@@ -409,7 +481,7 @@ impl PyBuffer {
     /// If the buffer is multi-dimensional, the elements are written in C-style order.
     ///
     /// Fails if the buffer format is not compatible with type `T`.
-    pub fn to_vec<T: Element+Copy>(&self, py: Python) -> PyResult<Vec<T>> {
+    pub fn to_vec<T: Element + Copy>(&self, py: Python) -> PyResult<Vec<T>> {
         self.to_vec_impl(py, b'C')
     }
 
@@ -417,11 +489,11 @@ impl PyBuffer {
     /// If the buffer is multi-dimensional, the elements are written in Fortran-style order.
     ///
     /// Fails if the buffer format is not compatible with type `T`.
-    pub fn to_fortran_vec<T: Element+Copy>(&self, py: Python) -> PyResult<Vec<T>> {
+    pub fn to_fortran_vec<T: Element + Copy>(&self, py: Python) -> PyResult<Vec<T>> {
         self.to_vec_impl(py, b'F')
     }
 
-    fn to_vec_impl<T: Element+Copy>(&self, py: Python, fort: u8) -> PyResult<Vec<T>> {
+    fn to_vec_impl<T: Element + Copy>(&self, py: Python, fort: u8) -> PyResult<Vec<T>> {
         if !T::is_compatible_format(self.format()) || mem::size_of::<T>() != self.item_size() {
             incompatible_format_error(py)?;
             unreachable!();
@@ -431,12 +503,15 @@ impl PyBuffer {
         unsafe {
             // Copy the buffer into the uninitialized space in the vector.
             // Due to T:Copy, we don't need to be concerned with Drop impls.
-            err::error_on_minusone(py, ffi::PyBuffer_ToContiguous(
-                vec.as_mut_ptr() as *mut libc::c_void,
-                &*self.0 as *const ffi::Py_buffer as *mut ffi::Py_buffer,
-                self.0.len,
-                fort as libc::c_char
-            ))?;
+            err::error_on_minusone(
+                py,
+                ffi::PyBuffer_ToContiguous(
+                    vec.as_mut_ptr() as *mut libc::c_void,
+                    &*self.0 as *const ffi::Py_buffer as *mut ffi::Py_buffer,
+                    self.0.len,
+                    fort as libc::c_char,
+                ),
+            )?;
             // set vector length to mark the now-initialized space as usable
             vec.set_len(item_count);
         }
@@ -453,10 +528,10 @@ impl PyBuffer {
     /// To check whether the buffer format is compatible before calling this method,
     /// use `<T as buffer::Element>::is_compatible_format(buf.format())`.
     /// Alternatively, `match buffer::ElementType::from_format(buf.format())`.
-    pub fn copy_from_slice<T: Element+Copy>(&self, py: Python, source: &[T]) -> PyResult<()> {
+    pub fn copy_from_slice<T: Element + Copy>(&self, py: Python, source: &[T]) -> PyResult<()> {
         self.copy_from_slice_impl(py, source, b'C')
     }
-    
+
     /// Copies the specified slice into the buffer.
     /// If the buffer is multi-dimensional, the elements in the slice are expected to be in Fortran-style order.
     ///
@@ -467,11 +542,20 @@ impl PyBuffer {
     /// To check whether the buffer format is compatible before calling this method,
     /// use `<T as buffer::Element>::is_compatible_format(buf.format())`.
     /// Alternatively, `match buffer::ElementType::from_format(buf.format())`.
-    pub fn copy_from_fortran_slice<T: Element+Copy>(&self, py: Python, source: &[T]) -> PyResult<()> {
+    pub fn copy_from_fortran_slice<T: Element + Copy>(
+        &self,
+        py: Python,
+        source: &[T],
+    ) -> PyResult<()> {
         self.copy_from_slice_impl(py, source, b'F')
     }
-    
-    fn copy_from_slice_impl<T: Element+Copy>(&self, py: Python, source: &[T], fort: u8) -> PyResult<()> {
+
+    fn copy_from_slice_impl<T: Element + Copy>(
+        &self,
+        py: Python,
+        source: &[T],
+        fort: u8,
+    ) -> PyResult<()> {
         if self.readonly() {
             return buffer_readonly_error(py);
         }
@@ -482,26 +566,38 @@ impl PyBuffer {
             return incompatible_format_error(py);
         }
         unsafe {
-            err::error_on_minusone(py, ffi::PyBuffer_FromContiguous(
-                &*self.0 as *const ffi::Py_buffer as *mut ffi::Py_buffer,
-                source.as_ptr() as *mut libc::c_void,
-                self.0.len,
-                fort as libc::c_char
-            ))
+            err::error_on_minusone(
+                py,
+                ffi::PyBuffer_FromContiguous(
+                    &*self.0 as *const ffi::Py_buffer as *mut ffi::Py_buffer,
+                    source.as_ptr() as *mut libc::c_void,
+                    self.0.len,
+                    fort as libc::c_char,
+                ),
+            )
         }
     }
 }
 
 fn slice_length_error(py: Python) -> PyResult<()> {
-    Err(err::PyErr::new::<exc::BufferError, _>(py, "Slice length does not match buffer length."))
+    Err(err::PyErr::new::<exc::BufferError, _>(
+        py,
+        "Slice length does not match buffer length.",
+    ))
 }
 
 fn incompatible_format_error(py: Python) -> PyResult<()> {
-    Err(err::PyErr::new::<exc::BufferError, _>(py, "Slice type is incompatible with buffer format."))
+    Err(err::PyErr::new::<exc::BufferError, _>(
+        py,
+        "Slice type is incompatible with buffer format.",
+    ))
 }
 
 fn buffer_readonly_error(py: Python) -> PyResult<()> {
-    Err(err::PyErr::new::<exc::BufferError, _>(py, "Cannot write to read-only buffer."))
+    Err(err::PyErr::new::<exc::BufferError, _>(
+        py,
+        "Cannot write to read-only buffer.",
+    ))
 }
 
 impl PyDrop for PyBuffer {
@@ -525,7 +621,7 @@ impl Drop for PyBuffer {
 ///  be modifying the data.
 pub struct ReadOnlyCell<T>(cell::UnsafeCell<T>);
 
-impl <T: Copy> ReadOnlyCell<T> {
+impl<T: Copy> ReadOnlyCell<T> {
     #[inline]
     pub fn get(&self) -> T {
         unsafe { *self.0.get() }
@@ -566,17 +662,20 @@ impl_element!(f64, Float);
 
 #[cfg(test)]
 mod test {
-    use std;
-    use python::{Python, PythonObject, PyDrop};
-    use conversion::ToPyObject;
-    use objects::{PySequence, PyList, PyTuple, PyIterator};
-    use objectprotocol::ObjectProtocol;
     use super::PyBuffer;
+    use conversion::ToPyObject;
+    use objectprotocol::ObjectProtocol;
+    use objects::{PyIterator, PyList, PySequence, PyTuple};
+    use python::{PyDrop, Python, PythonObject};
+    use std;
 
     #[test]
     fn test_compatible_size() {
         // for the cast in PyBuffer::shape()
-        assert_eq!(std::mem::size_of::<::Py_ssize_t>(), std::mem::size_of::<usize>());
+        assert_eq!(
+            std::mem::size_of::<::Py_ssize_t>(),
+            std::mem::size_of::<usize>()
+        );
     }
 
     #[test]
@@ -609,18 +708,23 @@ mod test {
         assert_eq!(arr, b"abcde" as &[u8]);
 
         assert!(buffer.copy_from_slice(py, &[0u8; 5]).is_err());
-        
+
         assert!(buffer.to_vec::<i8>(py).is_err());
         assert!(buffer.to_vec::<u16>(py).is_err());
         assert_eq!(buffer.to_vec::<u8>(py).unwrap(), b"abcde");
     }
 
     #[test]
-    #[cfg(feature="python3-sys")] // array.array doesn't implement the buffer protocol in python 2.7
+    #[cfg(feature = "python3-sys")] // array.array doesn't implement the buffer protocol in python 2.7
     fn test_array_buffer() {
         let gil = Python::acquire_gil();
         let py = gil.python();
-        let array = py.import("array").unwrap().as_object().call_method(py, "array", ("f", (1.0, 1.5, 2.0, 2.5)), None).unwrap();
+        let array = py
+            .import("array")
+            .unwrap()
+            .as_object()
+            .call_method(py, "array", ("f", (1.0, 1.5, 2.0, 2.5)), None)
+            .unwrap();
         let buffer = PyBuffer::get(py, &array).unwrap();
         assert_eq!(buffer.dimensions(), 1);
         assert_eq!(buffer.item_count(), 4);
@@ -634,17 +738,18 @@ mod test {
         assert_eq!(slice.len(), 4);
         assert_eq!(slice[0].get(), 1.0);
         assert_eq!(slice[3].get(), 2.5);
-        
+
         let mut_slice = buffer.as_mut_slice::<f32>(py).unwrap();
         assert_eq!(mut_slice.len(), 4);
         assert_eq!(mut_slice[0].get(), 1.0);
         mut_slice[3].set(2.75);
         assert_eq!(slice[3].get(), 2.75);
 
-        buffer.copy_from_slice(py, &[10.0f32, 11.0, 12.0, 13.0]).unwrap();
+        buffer
+            .copy_from_slice(py, &[10.0f32, 11.0, 12.0, 13.0])
+            .unwrap();
         assert_eq!(slice[2].get(), 12.0);
 
         assert_eq!(buffer.to_vec::<f32>(py).unwrap(), [10.0, 11.0, 12.0, 13.0]);
     }
 }
-
