@@ -16,18 +16,20 @@
 // OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 // DEALINGS IN THE SOFTWARE.
 
-use std;
-use python::{PythonObject, ToPythonPointer, Python, PythonObjectDowncastError,
-        PythonObjectWithTypeObject, PyClone, PyDrop};
-use objects::{PyObject, PyType, exc};
-#[cfg(feature="python27-sys")]
-use objects::oldstyle::PyClass;
+use conversion::ToPyObject;
 use ffi;
 use libc;
-use std::ptr;
 use libc::c_char;
-use conversion::ToPyObject;
+#[cfg(feature = "python27-sys")]
+use objects::oldstyle::PyClass;
+use objects::{exc, PyObject, PyType};
+use python::{
+    PyClone, PyDrop, Python, PythonObject, PythonObjectDowncastError, PythonObjectWithTypeObject,
+    ToPythonPointer,
+};
+use std;
 use std::ffi::CString;
+use std::ptr;
 
 /**
 Defines a new exception type.
@@ -67,31 +69,48 @@ macro_rules! py_exception {
         pyobject_newtype!($name);
 
         impl $name {
-            pub fn new<'p, T: $crate::ToPyObject>(py: $crate::Python<'p>, args: T) -> $crate::PyErr {
+            pub fn new<'p, T: $crate::ToPyObject>(
+                py: $crate::Python<'p>,
+                args: T,
+            ) -> $crate::PyErr {
                 $crate::PyErr::new::<$name, T>(py, args)
             }
         }
 
         impl $crate::PythonObjectWithCheckedDowncast for $name {
             #[inline]
-            fn downcast_from<'p>(py: $crate::Python<'p>, obj: $crate::PyObject)
-                -> Result<$name, $crate::PythonObjectDowncastError<'p>>
-            {
-                if <$name as $crate::PythonObjectWithTypeObject>::type_object(py).is_instance(py, &obj) {
+            fn downcast_from<'p>(
+                py: $crate::Python<'p>,
+                obj: $crate::PyObject,
+            ) -> Result<$name, $crate::PythonObjectDowncastError<'p>> {
+                if <$name as $crate::PythonObjectWithTypeObject>::type_object(py)
+                    .is_instance(py, &obj)
+                {
                     Ok(unsafe { $crate::PythonObject::unchecked_downcast_from(obj) })
                 } else {
-                    Err($crate::PythonObjectDowncastError(py))
+                    Err($crate::PythonObjectDowncastError::new(
+                        py,
+                        _cpython__err__stringify!($name),
+                        <$name as $crate::PythonObjectWithTypeObject>::type_object(py),
+                    ))
                 }
             }
 
             #[inline]
-            fn downcast_borrow_from<'a, 'p>(py: $crate::Python<'p>, obj: &'a $crate::PyObject)
-                -> Result<&'a $name, $crate::PythonObjectDowncastError<'p>>
-            {
-                if <$name as $crate::PythonObjectWithTypeObject>::type_object(py).is_instance(py, obj) {
+            fn downcast_borrow_from<'a, 'p>(
+                py: $crate::Python<'p>,
+                obj: &'a $crate::PyObject,
+            ) -> Result<&'a $name, $crate::PythonObjectDowncastError<'p>> {
+                if <$name as $crate::PythonObjectWithTypeObject>::type_object(py)
+                    .is_instance(py, obj)
+                {
                     Ok(unsafe { $crate::PythonObject::unchecked_downcast_borrow_from(obj) })
                 } else {
-                    Err($crate::PythonObjectDowncastError(py))
+                    Err($crate::PythonObjectDowncastError::new(
+                        py,
+                        _cpython__err__stringify!($name),
+                        <$name as $crate::PythonObjectWithTypeObject>::type_object(py),
+                    ))
                 }
             }
         }
@@ -100,14 +119,21 @@ macro_rules! py_exception {
             #[inline]
             fn type_object(py: $crate::Python) -> $crate::PyType {
                 unsafe {
-                    static mut type_object: *mut $crate::_detail::ffi::PyTypeObject = 0 as *mut $crate::_detail::ffi::PyTypeObject;
+                    static mut type_object: *mut $crate::_detail::ffi::PyTypeObject =
+                        0 as *mut $crate::_detail::ffi::PyTypeObject;
 
                     if type_object.is_null() {
                         type_object = $crate::PyErr::new_type(
                             py,
-                            _cpython__err__concat!(_cpython__err__stringify!($module), ".", _cpython__err__stringify!($name)),
+                            _cpython__err__concat!(
+                                _cpython__err__stringify!($module),
+                                ".",
+                                _cpython__err__stringify!($name)
+                            ),
                             Some($crate::PythonObject::into_object(py.get_type::<$base>())),
-                            None).as_type_ptr();
+                            None,
+                        )
+                        .as_type_ptr();
                     }
 
                     $crate::PyType::from_type_ptr(py, type_object)
@@ -117,26 +143,25 @@ macro_rules! py_exception {
     };
     ($module: ident, $name: ident) => {
         py_exception!($module, $name, $crate::exc::Exception);
-    }
+    };
 }
 
 /// Represents a Python exception that was raised.
 #[derive(Debug)]
 pub struct PyErr {
     /// The type of the exception. This should be either a `PyClass` or a `PyType`.
-    pub ptype : PyObject,
+    pub ptype: PyObject,
     /// The value of the exception.
     ///
     /// This can be either an instance of `ptype`,
     /// a tuple of arguments to be passed to `ptype`'s constructor,
     /// or a single argument to be passed to `ptype`'s constructor.
     /// Call `PyErr::instance()` to get the exception instance in all cases.
-    pub pvalue : Option<PyObject>,
+    pub pvalue: Option<PyObject>,
     /// The `PyTraceBack` object associated with the error.
-    pub ptraceback : Option<PyObject>
+    pub ptraceback: Option<PyObject>,
 }
 
-
 /// Represents the result of a Python call.
 pub type PyResult<T> = Result<T, PyErr>;
 
@@ -153,14 +178,16 @@ impl PyErr {
     /// Example:
     ///  `return Err(PyErr::new::<exc::TypeError, _>(py, "Error message"));`
     pub fn new<T, V>(py: Python, value: V) -> PyErr
-        where T: PythonObjectWithTypeObject, V: ToPyObject
+    where
+        T: PythonObjectWithTypeObject,
+        V: ToPyObject,
     {
         PyErr::new_helper(py, py.get_type::<T>(), value.to_py_object(py).into_object())
     }
 
     /// Gets whether an error is present in the Python interpreter's global state.
     #[inline]
-    pub fn occurred(_ : Python) -> bool {
+    pub fn occurred(_: Python) -> bool {
         unsafe { !ffi::PyErr_Occurred().is_null() }
     }
 
@@ -169,22 +196,26 @@ impl PyErr {
     ///
     /// `base` can be an existing exception type to subclass, or a tuple of classes
     /// `dict` specifies an optional dictionary of class variables and methods
-    pub fn new_type(py: Python, name: &str, base: Option<PyObject>, dict: Option<PyObject>) -> PyType {
+    pub fn new_type(
+        py: Python,
+        name: &str,
+        base: Option<PyObject>,
+        dict: Option<PyObject>,
+    ) -> PyType {
         let base: *mut ffi::PyObject = match base {
             None => ptr::null_mut(),
-            Some(obj) => obj.steal_ptr()
+            Some(obj) => obj.steal_ptr(),
         };
 
         let dict: *mut ffi::PyObject = match dict {
             None => ptr::null_mut(),
-            Some(obj) => obj.steal_ptr()
+            Some(obj) => obj.steal_ptr(),
         };
 
         unsafe {
             let null_terminated_name = CString::new(name).unwrap();
-            let ptr: *mut ffi::PyObject = ffi::PyErr_NewException(null_terminated_name.as_ptr() as *mut c_char,
-                                                                  base,
-                                                                  dict);
+            let ptr: *mut ffi::PyObject =
+                ffi::PyErr_NewException(null_terminated_name.as_ptr() as *mut c_char, base, dict);
             PyObject::from_borrowed_ptr(py, ptr).unchecked_cast_into::<PyType>()
         }
     }
@@ -192,27 +223,32 @@ impl PyErr {
     /// Retrieves the current error from the Python interpreter's global state.
     /// The error is cleared from the Python interpreter.
     /// If no error is set, returns a `SystemError`.
-    pub fn fetch(py : Python) -> PyErr {
+    pub fn fetch(py: Python) -> PyErr {
         unsafe {
-            let mut ptype      : *mut ffi::PyObject = std::mem::uninitialized();
-            let mut pvalue     : *mut ffi::PyObject = std::mem::uninitialized();
-            let mut ptraceback : *mut ffi::PyObject = std::mem::uninitialized();
+            let mut ptype: *mut ffi::PyObject = std::mem::uninitialized();
+            let mut pvalue: *mut ffi::PyObject = std::mem::uninitialized();
+            let mut ptraceback: *mut ffi::PyObject = std::mem::uninitialized();
             ffi::PyErr_Fetch(&mut ptype, &mut pvalue, &mut ptraceback);
             PyErr::new_from_ffi_tuple(py, ptype, pvalue, ptraceback)
         }
     }
 
-    unsafe fn new_from_ffi_tuple(py: Python, ptype: *mut ffi::PyObject, pvalue: *mut ffi::PyObject, ptraceback: *mut ffi::PyObject) -> PyErr {
+    unsafe fn new_from_ffi_tuple(
+        py: Python,
+        ptype: *mut ffi::PyObject,
+        pvalue: *mut ffi::PyObject,
+        ptraceback: *mut ffi::PyObject,
+    ) -> PyErr {
         // Note: must not panic to ensure all owned pointers get acquired correctly,
         // and because we mustn't panic in normalize().
         PyErr {
             ptype: if ptype.is_null() {
-                        py.get_type::<exc::SystemError>().into_object()
-                   } else {
-                        PyObject::from_owned_ptr(py, ptype)
-                   },
+                py.get_type::<exc::SystemError>().into_object()
+            } else {
+                PyObject::from_owned_ptr(py, ptype)
+            },
             pvalue: PyObject::from_owned_ptr_opt(py, pvalue),
-            ptraceback: PyObject::from_owned_ptr_opt(py, ptraceback)
+            ptraceback: PyObject::from_owned_ptr_opt(py, ptraceback),
         }
     }
 
@@ -221,7 +257,7 @@ impl PyErr {
         PyErr {
             ptype: ty.into_object(),
             pvalue: Some(value),
-            ptraceback: None
+            ptraceback: None,
         }
     }
 
@@ -230,28 +266,37 @@ impl PyErr {
     /// `obj` must be an Python exception instance, the PyErr will use that instance.
     /// If `obj` is a Python exception type object, the PyErr will (lazily) create a new instance of that type.
     /// Otherwise, a `TypeError` is created instead.
-    pub fn from_instance<O>(py: Python, obj: O) -> PyErr where O: PythonObject {
+    pub fn from_instance<O>(py: Python, obj: O) -> PyErr
+    where
+        O: PythonObject,
+    {
         PyErr::from_instance_helper(py, obj.into_object())
     }
 
     fn from_instance_helper(py: Python, obj: PyObject) -> PyErr {
         if unsafe { ffi::PyExceptionInstance_Check(obj.as_ptr()) } != 0 {
             PyErr {
-                ptype: unsafe { PyObject::from_borrowed_ptr(py, ffi::PyExceptionInstance_Class(obj.as_ptr())) },
+                ptype: unsafe {
+                    PyObject::from_borrowed_ptr(py, ffi::PyExceptionInstance_Class(obj.as_ptr()))
+                },
                 pvalue: Some(obj),
-                ptraceback: None
+                ptraceback: None,
             }
         } else if unsafe { ffi::PyExceptionClass_Check(obj.as_ptr()) } != 0 {
             PyErr {
                 ptype: obj,
                 pvalue: None,
-                ptraceback: None
+                ptraceback: None,
             }
         } else {
             PyErr {
                 ptype: py.get_type::<exc::TypeError>().into_object(),
-                pvalue: Some("exceptions must derive from BaseException".to_py_object(py).into_object()),
-                ptraceback: None
+                pvalue: Some(
+                    "exceptions must derive from BaseException"
+                        .to_py_object(py)
+                        .into_object(),
+                ),
+                ptraceback: None,
             }
         }
     }
@@ -264,7 +309,7 @@ impl PyErr {
         PyErr {
             ptype: exc.into_object(),
             pvalue: value,
-            ptraceback: None
+            ptraceback: None,
         }
     }
 
@@ -284,7 +329,8 @@ impl PyErr {
     /// If `exc` is a class object, this also returns `true` when `self` is an instance of a subclass.
     /// If `exc` is a tuple, all exceptions in the tuple (and recursively in subtuples) are searched for a match.
     pub fn matches<T>(&self, py: Python, exc: T) -> bool
-        where T: ToPyObject
+    where
+        T: ToPyObject,
     {
         exc.with_borrowed_ptr(py, |exc| unsafe {
             ffi::PyErr_GivenExceptionMatches(self.ptype.as_ptr(), exc) != 0
@@ -304,7 +350,11 @@ impl PyErr {
     /// Helper function for normalizing the error by deconstructing and reconstructing the PyErr.
     /// Must not panic for safety in normalize()
     fn into_normalized(self, py: Python) -> PyErr {
-        let PyErr { ptype, pvalue, ptraceback } = self;
+        let PyErr {
+            ptype,
+            pvalue,
+            ptraceback,
+        } = self;
         let mut ptype = ptype.steal_ptr();
         let mut pvalue = pvalue.steal_ptr(py);
         let mut ptraceback = ptraceback.steal_ptr(py);
@@ -317,24 +367,23 @@ impl PyErr {
     /// Retrieves the exception type.
     ///
     /// If the exception type is an old-style class, returns `oldstyle::PyClass`.
-    #[cfg(feature="python27-sys")]
+    #[cfg(feature = "python27-sys")]
     pub fn get_type(&self, py: Python) -> PyType {
         match self.ptype.cast_as::<PyType>(py) {
-            Ok(t)  => t.clone_ref(py),
-            Err(_) =>
-                match self.ptype.cast_as::<PyClass>(py) {
-                    Ok(_)  => py.get_type::<PyClass>(),
-                    Err(_) => py.None().get_type(py)
-                }
+            Ok(t) => t.clone_ref(py),
+            Err(_) => match self.ptype.cast_as::<PyClass>(py) {
+                Ok(_) => py.get_type::<PyClass>(),
+                Err(_) => py.None().get_type(py),
+            },
         }
     }
 
     /// Retrieves the exception type.
-    #[cfg(not(feature="python27-sys"))]
+    #[cfg(not(feature = "python27-sys"))]
     pub fn get_type(&self, py: Python) -> PyType {
         match self.ptype.cast_as::<PyType>(py) {
-            Ok(t)  => t.clone_ref(py),
-            Err(_) => py.None().get_type(py)
+            Ok(t) => t.clone_ref(py),
+            Err(_) => py.None().get_type(py),
         }
     }
 
@@ -345,7 +394,7 @@ impl PyErr {
         self.normalize(py);
         match self.pvalue {
             Some(ref instance) => instance.clone_ref(py),
-            None => py.None()
+            None => py.None(),
         }
     }
 
@@ -353,9 +402,17 @@ impl PyErr {
     /// This is the opposite of `PyErr::fetch()`.
     #[inline]
     pub fn restore(self, py: Python) {
-        let PyErr { ptype, pvalue, ptraceback } = self;
+        let PyErr {
+            ptype,
+            pvalue,
+            ptraceback,
+        } = self;
         unsafe {
-            ffi::PyErr_Restore(ptype.steal_ptr(), pvalue.steal_ptr(py), ptraceback.steal_ptr(py))
+            ffi::PyErr_Restore(
+                ptype.steal_ptr(),
+                pvalue.steal_ptr(py),
+                ptraceback.steal_ptr(py),
+            )
         }
     }
 
@@ -364,7 +421,14 @@ impl PyErr {
     pub fn warn(py: Python, category: &PyObject, message: &str, stacklevel: i32) -> PyResult<()> {
         let message = CString::new(message).unwrap();
         unsafe {
-            error_on_minusone(py, ffi::PyErr_WarnEx(category.as_ptr(), message.as_ptr(), stacklevel as ffi::Py_ssize_t))
+            error_on_minusone(
+                py,
+                ffi::PyErr_WarnEx(
+                    category.as_ptr(),
+                    message.as_ptr(),
+                    stacklevel as ffi::Py_ssize_t,
+                ),
+            )
         }
     }
 }
@@ -382,15 +446,22 @@ impl PyClone for PyErr {
         PyErr {
             ptype: self.ptype.clone_ref(py),
             pvalue: self.pvalue.clone_ref(py),
-            ptraceback: self.ptraceback.clone_ref(py)
+            ptraceback: self.ptraceback.clone_ref(py),
         }
     }
 }
 
 /// Converts `PythonObjectDowncastError` to Python `TypeError`.
-impl <'p> std::convert::From<PythonObjectDowncastError<'p>> for PyErr {
+impl<'p> std::convert::From<PythonObjectDowncastError<'p>> for PyErr {
     fn from(err: PythonObjectDowncastError<'p>) -> PyErr {
-        PyErr::new_lazy_init(err.0.get_type::<exc::TypeError>(), None)
+        let msg = format!(
+            "Expected type that converts to {} but received {}",
+            err.expected_type_name,
+            err.received_type.name(err.py),
+        )
+        .to_py_object(err.py)
+        .into_object();
+        PyErr::new_lazy_init(err.py.get_type::<exc::TypeError>(), Some(msg))
     }
 }
 
@@ -398,7 +469,7 @@ impl <'p> std::convert::From<PythonObjectDowncastError<'p>> for PyErr {
 /// Returns `Err(PyErr)` if the pointer is `null`.
 /// Unsafe because the pointer might be invalid.
 #[inline]
-pub unsafe fn result_from_owned_ptr(py : Python, p : *mut ffi::PyObject) -> PyResult<PyObject> {
+pub unsafe fn result_from_owned_ptr(py: Python, p: *mut ffi::PyObject) -> PyResult<PyObject> {
     if p.is_null() {
         Err(PyErr::fetch(py))
     } else {
@@ -407,12 +478,14 @@ pub unsafe fn result_from_owned_ptr(py : Python, p : *mut ffi::PyObject) -> PyRe
 }
 
 fn panic_after_error(_py: Python) -> ! {
-    unsafe { ffi::PyErr_Print(); }
+    unsafe {
+        ffi::PyErr_Print();
+    }
     panic!("Python API called failed");
 }
 
 #[inline]
-pub unsafe fn from_owned_ptr_or_panic(py : Python, p : *mut ffi::PyObject) -> PyObject {
+pub unsafe fn from_owned_ptr_or_panic(py: Python, p: *mut ffi::PyObject) -> PyObject {
     if p.is_null() {
         panic_after_error(py);
     } else {
@@ -420,8 +493,9 @@ pub unsafe fn from_owned_ptr_or_panic(py : Python, p : *mut ffi::PyObject) -> Py
     }
 }
 
-pub unsafe fn result_cast_from_owned_ptr<T>(py : Python, p : *mut ffi::PyObject) -> PyResult<T>
-    where T: ::python::PythonObjectWithCheckedDowncast
+pub unsafe fn result_cast_from_owned_ptr<T>(py: Python, p: *mut ffi::PyObject) -> PyResult<T>
+where
+    T: ::python::PythonObjectWithCheckedDowncast,
 {
     if p.is_null() {
         Err(PyErr::fetch(py))
@@ -430,8 +504,9 @@ pub unsafe fn result_cast_from_owned_ptr<T>(py : Python, p : *mut ffi::PyObject)
     }
 }
 
-pub unsafe fn cast_from_owned_ptr_or_panic<T>(py : Python, p : *mut ffi::PyObject) -> T
-    where T: ::python::PythonObjectWithCheckedDowncast
+pub unsafe fn cast_from_owned_ptr_or_panic<T>(py: Python, p: *mut ffi::PyObject) -> T
+where
+    T: ::python::PythonObjectWithCheckedDowncast,
 {
     if p.is_null() {
         panic_after_error(py);
@@ -442,7 +517,7 @@ pub unsafe fn cast_from_owned_ptr_or_panic<T>(py : Python, p : *mut ffi::PyObjec
 
 /// Returns Ok if the error code is not -1.
 #[inline]
-pub fn error_on_minusone(py : Python, result : libc::c_int) -> PyResult<()> {
+pub fn error_on_minusone(py: Python, result: libc::c_int) -> PyResult<()> {
     if result != -1 {
         Ok(())
     } else {
@@ -450,7 +525,6 @@ pub fn error_on_minusone(py : Python, result : libc::c_int) -> PyResult<()> {
     }
 }
 
-
 // 2018 macros support
 //
 #[doc(hidden)]
@@ -471,8 +545,8 @@ macro_rules! _cpython__err__stringify {
 
 #[cfg(test)]
 mod tests {
-    use {Python, PyErr};
     use objects::exc;
+    use {PyErr, Python};
 
     #[test]
     fn set_typeerror() {
@@ -483,5 +557,3 @@ mod tests {
         drop(PyErr::fetch(py));
     }
 }
-
-
