@@ -122,6 +122,22 @@ impl MyType {
 }
 ```
 
+## Shared data declarations
+`@shared data data_name: data_type;`
+
+Declares a "shareable" data field within the Python class.
+A data field of this type can be borrowed immutably by another Python object
+such as a Python iterator. See [PySharedRefCell] documentation for details.
+
+On the Rust side, data is accessed through the automatically generated accessor functions:
+```ignore
+impl MyType {
+    fn data_name<'a>(&'a self, py: Python<'a>) -> PySharedRef<'a, $data_type> { ... }
+}
+```
+
+[PySharedRefCell]: struct.PySharedRefCell.html
+
 ## Instance methods
 `def method_name(&self, parameter-list) -> PyResult<...> { ... }`
 
@@ -396,6 +412,15 @@ py_class!(class MyIterator |py| {
     The return type must be `PyResult<T>` for some `T` that implements `ToPyObject`.
 
 
+# Errors
+
+* If argument parsing fails, the Rust method body will not be called and an
+  appropriate Python exception is raised instead (usually `TypeError`
+  when the Python value does not match the expected type;
+  the implementation of `FromPyObject` for your type may document additional
+  errors).
+* If a method panics in Rust, a Python `SystemError` will be raised.
+
 */
 #[macro_export]
 macro_rules! py_class {
@@ -411,7 +436,7 @@ macro_rules! py_class {
                     /* traverse_proc: */ None,
                     /* traverse_data: */ [ /*name*/ ]
                 },
-                /* data: */ [ /* { offset, name, type } */ ]
+                /* data: */ [ /* { offset, name, type, init_expr, init_type } */ ]
                 // TODO: base type, documentation, ...
             }
             /* slots: */ {
@@ -440,7 +465,7 @@ macro_rules! py_class {
                     /* traverse_proc: */ None,
                     /* traverse_data: */ [ /*name*/ ]
                 },
-                /* data: */ [ /* { offset, name, type } */ ]
+                /* data: */ [ /* { offset, name, type, init_expr, init_type } */ ]
                 // TODO: base type, documentation, ...
             }
             /* slots: */ {
