@@ -45,7 +45,7 @@ base_case = '''
             $size:expr,
             { $( $class_visibility:tt )* },
             $gc:tt,
-            /* data: */ [ $( { $data_offset:expr, $data_name:ident, $data_ty:ty } )* ]
+            /* data: */ [ $( { $data_offset:expr, $data_name:ident, $data_ty:ty, $init_expr:expr, $init_ty:ty } )* ]
         }
         $slots:tt { $( $imp:item )* } $members:tt
     } => {
@@ -88,7 +88,11 @@ base_case = '''
                 if py.get_type::<$class>().is_instance(py, &obj) {
                     Ok($class { _unsafe_inner: obj })
                 } else {
-                    Err($crate::PythonObjectDowncastError(py))
+                    Err($crate::PythonObjectDowncastError::new(
+                        py,
+                        _cpython__py_class__py_class_impl__stringify!($class),
+                        obj.get_type(py),
+                    ))
                 }
             }
 
@@ -97,14 +101,18 @@ base_case = '''
                 if py.get_type::<$class>().is_instance(py, obj) {
                     unsafe { Ok(::std::mem::transmute(obj)) }
                 } else {
-                    Err($crate::PythonObjectDowncastError(py))
+                    Err($crate::PythonObjectDowncastError::new(
+                        py,
+                        _cpython__py_class__py_class_impl__stringify!($class),
+                        obj.get_type(py),
+                    ))
                 }
             }
         }
 
         py_coerce_item! {
             impl $crate::py_class::BaseObject for $class {
-                type InitType = ( $( $data_ty, )* );
+                type InitType = ( $( $init_ty, )* );
 
                 #[inline]
                 fn size() -> usize {
@@ -118,7 +126,7 @@ base_case = '''
                 ) -> $crate::PyResult<$crate::PyObject>
                 {
                     let obj = <$base_type as $crate::py_class::BaseObject>::alloc(py, ty, ())?;
-                    $( $crate::py_class::data_init::<$data_ty>(py, &obj, $data_offset, $data_name); )*
+                    $( $crate::py_class::data_init::<$data_ty>(py, &obj, $data_offset, $init_expr); )*
                     Ok(obj)
                 }
 
@@ -131,7 +139,7 @@ base_case = '''
         $($imp)*
         py_coerce_item! {
             impl $class {
-                fn create_instance(py: $crate::Python $( , $data_name : $data_ty )* ) -> $crate::PyResult<$class> {
+                fn create_instance(py: $crate::Python $( , $data_name : $init_ty )* ) -> $crate::PyResult<$class> {
                     let obj = unsafe {
                         <$class as $crate::py_class::BaseObject>::alloc(
                             py, &py.get_type::<$class>(), ( $($data_name,)* )
@@ -342,7 +350,9 @@ def data_decl():
                 {
                     $crate::py_class::data_offset::<$data_type>($size),
                     $data_name,
-                    $data_type
+                    $data_type,
+                    /* init_expr: */ $data_name,
+                    /* init_ty: */ $data_type
                 }
             ]
         }
@@ -361,6 +371,43 @@ def data_decl():
             }
         ''')
 
+def shared_data_decl():
+    # the storage type is PySharedRefCell<$data_type>, but unlike plain "data",
+    # its reference type is PySharedRef<'a, $data_type>.
+    generate_case('@shared data $data_name:ident : $data_type:ty;',
+        new_info = '''
+        /* info: */ {
+            $base_type,
+            /* size: */ $crate::py_class::data_new_size::<$crate::PySharedRefCell<$data_type>>($size),
+            $class_visibility,
+            $gc,
+            /* data: */ [
+                $($data)*
+                {
+                    $crate::py_class::data_offset::<$crate::PySharedRefCell<$data_type>>($size),
+                    $data_name,
+                    /* data_ty: */ $crate::PySharedRefCell<$data_type>,
+                    /* init_expr: */ $crate::PySharedRefCell::<$data_type>::new($data_name),
+                    /* init_ty: */ $data_type
+                }
+            ]
+        }
+        ''',
+        new_impl='''
+            impl $class {
+                fn $data_name<'a>(&'a self, py: $crate::Python<'a>) -> $crate::PySharedRef<'a, $data_type> {
+                    unsafe {
+                        let data = $crate::py_class::data_get::<$crate::PySharedRefCell<$data_type>>(
+                            py,
+                            &self._unsafe_inner,
+                            $crate::py_class::data_offset::<$crate::PySharedRefCell<$data_type>>($size)
+                        );
+                        $crate::PySharedRef::new(py, &self._unsafe_inner, data)
+                    }
+                }
+            }
+        ''')
+
 def generate_class_method(special_name=None, decoration='',
         slot=None, add_member=False, value_macro=None, value_args=None):
     name_pattern = special_name or '$name:ident'
@@ -808,6 +855,7 @@ def main():
     print(macro_start)
     print(base_case)
     data_decl()
+    shared_data_decl()
     traverse_and_clear()
     for name, f in sorted(special_names.items()):
         f(name)
